pub struct Connection<PK>where
PK: PublicKey,{ /* private fields */ }Expand description
A bidirectional, encrypted and authenticated connection with a peer
the connection can be conveniently split into its halves (ConnectionWriter
and ConnectionReader) for more convenient handling of that the protocol
may be available to write data and receive data at different time.
Implementations
Sourceimpl<PK> Connection<PK>
impl<PK> Connection<PK>
Sourcepub fn remote_public_identity(&self) -> &PK
pub fn remote_public_identity(&self) -> &PK
retrieve the public identity of the peer
Sourcepub fn remote_address(&self) -> SocketAddr
pub fn remote_address(&self) -> SocketAddr
the remote address we are sending/receiving messages to/from
beware that this may not reflect the peer’s actual address as they may be behind routers. Also this is not the same as the address that may be advertised by the peer in the gossip as they might use a different port number or a different routes for inbounds or outbound connections depending on their IT configuration.
Sourcepub fn session_id(&self) -> &SessionId
pub fn session_id(&self) -> &SessionId
retrieve the unique identifier of the established session
this is derived from the NOISE handshake and is the same on both sides of the stream (here and for the remote).
Sourcepub async fn connect_to<RNG, K>(
rng: RNG,
k: &K,
peer_addr: SocketAddr,
rs: K::Public,
) -> Result<Self>
pub async fn connect_to<RNG, K>( rng: RNG, k: &K, peer_addr: SocketAddr, rs: K::Public, ) -> Result<Self>
connect to the given socket address, expecting the remote to identify
with the PublicKey rs.
The function will use the given RNG to generate an ephemeral private keys
that will be used only for this connection and the given key k to authenticate
ourself to the remote.
Sourcepub async fn connect<RNG, K, A>(
rng: RNG,
k: &K,
peer_addr: A,
rs: K::Public,
) -> Result<Self>
pub async fn connect<RNG, K, A>( rng: RNG, k: &K, peer_addr: A, rs: K::Public, ) -> Result<Self>
attempt to connect to any resolved lookup_host result of the given ToSocketAddrs.
The function will returns at the first successful attempt or once all the possible options have been tried and failed.
Sourcepub fn into_parts(self) -> (ConnectionReader<PK>, ConnectionWriter<PK>)
pub fn into_parts(self) -> (ConnectionReader<PK>, ConnectionWriter<PK>)
split the connections into 2 parts
this allows to have 2 different independent objects to read or write to/from the remote peer.