ConnectionWriter

Struct ConnectionWriter 

pub struct ConnectionWriter<PK>
where PK: PublicKey,
{ /* private fields */ }
writer halve of the authenticated encrypted connection with the peer

Implementations

Source

impl<PK> ConnectionWriter<PK>
where PK: PublicKey,

pub fn remote_public_identity(&self) -> &PK

retrieve the public identity of the peer

pub fn remote_address(&self) -> SocketAddr

the remote address we are sending messages to

beware that this may not reflect the peer’s actual address as they may be behind routers. Also this is not the same as the address that may be advertised by the peer in the gossip as they might use a different port number or a different routes for inbounds or outbound connections depending on their IT configuration.

pub fn session_id(&self) -> &SessionId

retrieve the unique identifier of the established session

this is derived from the NOISE handshake and is the same on both sides of the stream (here and for the remote).