Version

Struct Version 

pub struct Version(/* private fields */);
protocol version number

technically this is limited to 8 bytes. However it is easy to imagine than more than 256 version numbers are a bit overkill.

Versions will be listed here overtime. However when performing the handshake, this function will use Version::CURRENT and will check how the remote’s version match the Version::MIN and Version::MAX. See is_supported.

Implementations

Source

impl Version

pub const SIZE: usize

the encoded size of the Version.

assert_eq!(Version::SIZE, 1)
pub const V1: Self

version 1:

Support syncing passports between the nodes

pub const MIN: Self = Self::V1

get the minimal supported version supported by this implementation

pub const CURRENT: Self = Self::V1

get the current version implemented by this implementation

pub const MAX: Self = Self::CURRENT

get the maximal supported version supported by this implementation

pub fn is_supported(self) -> bool

returns if the version is currently supported or not

This is similar as to testing the given version against the increasing order:

assert!(
  Version::CURRENT.is_supported() ==
  (Version::CURRENT >= Version::MIN && Version::CURRENT <= Version::MAX)
);