pub struct ConnectionWriter<PK>where
PK: PublicKey,{ /* private fields */ }Expand description
writer halve of the authenticated encrypted connection with the peer
Implementations
Sourceimpl<PK> ConnectionWriter<PK>where
PK: PublicKey,
impl<PK> ConnectionWriter<PK>where
PK: PublicKey,
Sourcepub fn remote_public_identity(&self) -> &PK
pub fn remote_public_identity(&self) -> &PK
retrieve the public identity of the peer
Sourcepub fn remote_address(&self) -> SocketAddr
pub fn remote_address(&self) -> SocketAddr
the remote address we are sending messages to
beware that this may not reflect the peer’s actual address as they may be behind routers. Also this is not the same as the address that may be advertised by the peer in the gossip as they might use a different port number or a different routes for inbounds or outbound connections depending on their IT configuration.
Sourcepub fn session_id(&self) -> &SessionId
pub fn session_id(&self) -> &SessionId
retrieve the unique identifier of the established session
this is derived from the NOISE handshake and is the same on both sides of the stream (here and for the remote).